## Introduction

<!-- A detailed introduction to this scenario simulation project, below is an example:

This scenario simulation project using MMLU dataset to evaluate LLM-based agent's ability on different tasks.

There is one examiner agent (a static agent) who downloads the MMLU dataset from Hugging Face Datasets Hub.

In each round, the examiner agent broadcasts one sample to all examinee agents (a kind of dynamic agent whose number is not limited), each examinee agent need to choose an answer that it thinks is correct to respond.

When all samples are answered by all examinees, a reporter will generate a bar chart to show each examinee's answer accuracy.

-->

## Dependencies

Make sure you have all the additional required packages listed below installed in your environment before using this project:

<!-- make sure all listed dependencies are exactly the same as those in requirements.txt -->
<!-- 
un-comment to list dependencies in the code block below:

```txt
# requirements.txt
```
-->

You can copy above dependencies to a `requirements.txt` file and run `pip install -r requirements.txt` to install those dependencies.